guix-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[PATCH] build: ruby: Add support for tarball and directory sources.


From: David Thompson
Subject: [PATCH] build: ruby: Add support for tarball and directory sources.
Date: Mon, 07 Sep 2015 23:01:48 -0400
User-agent: Notmuch/0.20.2 (http://notmuchmail.org) Emacs/24.5.1 (x86_64-unknown-linux-gnu)

>From 612a4a692375f241934de03d24064dbef1c7294c Mon Sep 17 00:00:00 2001
From: David Thompson <address@hidden>
Date: Mon, 7 Sep 2015 22:58:05 -0400
Subject: [PATCH] build: ruby: Add support for tarball and directory sources.

Previously, the Ruby build system only knew how to work with gem archives,
which made it difficult to build unreleased gems from a Git repository or
released gems in tarball form.

* gnu/build/ruby-build-system.scm (gnu:unpack, gem-archive?): New procedures.
  (unpack): Use GNU build system unpack phase for non-gem sources.
  (build): Rebuild the gemspec iff the source is a gem archive.
---
 guix/build/ruby-build-system.scm | 86 ++++++++++++++++++++++------------------
 1 file changed, 48 insertions(+), 38 deletions(-)

diff --git a/guix/build/ruby-build-system.scm b/guix/build/ruby-build-system.scm
index 4184ccc..2685da1 100644
--- a/guix/build/ruby-build-system.scm
+++ b/guix/build/ruby-build-system.scm
@@ -41,53 +41,63 @@ directory."
     ((file-name . _) file-name)
     (() (error "No files matching pattern: " pattern))))
 
+(define gnu:unpack (assq-ref gnu:%standard-phases 'unpack))
+
+(define (gem-archive? file-name)
+  (string-match "^.*\\.gem$" file-name))
+
 (define* (unpack #:key source #:allow-other-keys)
   "Unpack the gem SOURCE and enter the resulting directory."
-  (and (zero? (system* "gem" "unpack" source))
-       ;; The unpacked gem directory is named the same as the archive, sans
-       ;; the ".gem" extension.  It is renamed to simply "gem" in an effort to
-       ;; keep file names shorter to avoid UNIX-domain socket file names and
-       ;; shebangs that exceed the system's fixed maximum length when running
-       ;; test suites.
-       (let ((dir (match:substring (string-match "^(.*)\\.gem$"
-                                                 (basename source))
-                                   1)))
-         (rename-file dir "gem")
-         (chdir "gem")
-         #t)))
+  (if (gem-archive? source)
+      (and (zero? (system* "gem" "unpack" source))
+           ;; The unpacked gem directory is named the same as the archive,
+           ;; sans the ".gem" extension.  It is renamed to simply "gem" in an
+           ;; effort to keep file names shorter to avoid UNIX-domain socket
+           ;; file names and shebangs that exceed the system's fixed maximum
+           ;; length when running test suites.
+           (let ((dir (match:substring (string-match "^(.*)\\.gem$"
+                                                     (basename source))
+                                       1)))
+             (rename-file dir "gem")
+             (chdir "gem")
+             #t))
+      ;; Use GNU unpack strategy for things that aren't gem archives.
+      (gnu:unpack #:source source)))
 
 (define* (build #:key source #:allow-other-keys)
   "Build a new gem using the gemspec from the SOURCE gem."
+  (define (first-gemspec)
+    (first-matching-file "\\.gemspec$"))
 
   ;; Remove the original gemspec, if present, and replace it with a new one.
   ;; This avoids issues with upstream gemspecs requiring tools such as git to
   ;; generate the files list.
-  (let ((gemspec (or (false-if-exception
-                      (first-matching-file "\\.gemspec$"))
-                     ;; Make new gemspec if one wasn't shipped.
-                     ".gemspec")))
-
-    (when (file-exists? gemspec) (delete-file gemspec))
-
-    ;; Extract gemspec from source gem.
-    (let ((pipe (open-pipe* OPEN_READ "gem" "spec" "--ruby" source)))
-      (dynamic-wind
-        (const #t)
-        (lambda ()
-          (call-with-output-file gemspec
-            (lambda (out)
-              ;; 'gem spec' writes to stdout, but 'gem build' only reads
-              ;; gemspecs from a file, so we redirect the output to a file.
-              (while (not (eof-object? (peek-char pipe)))
-                (write-char (read-char pipe) out))))
-          #t)
-        (lambda ()
-          (close-pipe pipe))))
-
-    ;; Build a new gem from the current working directory.  This also allows 
any
-    ;; dynamic patching done in previous phases to be present in the installed
-    ;; gem.
-    (zero? (system* "gem" "build" gemspec))))
+  (when (gem-archive? source)
+    (let ((gemspec (or (false-if-exception (first-gemspec))
+                       ;; Make new gemspec if one wasn't shipped.
+                       ".gemspec")))
+
+      (when (file-exists? gemspec) (delete-file gemspec))
+
+      ;; Extract gemspec from source gem.
+      (let ((pipe (open-pipe* OPEN_READ "gem" "spec" "--ruby" source)))
+        (dynamic-wind
+          (const #t)
+          (lambda ()
+            (call-with-output-file gemspec
+              (lambda (out)
+                ;; 'gem spec' writes to stdout, but 'gem build' only reads
+                ;; gemspecs from a file, so we redirect the output to a file.
+                (while (not (eof-object? (peek-char pipe)))
+                  (write-char (read-char pipe) out))))
+            #t)
+          (lambda ()
+            (close-pipe pipe))))))
+
+  ;; Build a new gem from the current working directory.  This also allows any
+  ;; dynamic patching done in previous phases to be present in the installed
+  ;; gem.
+  (zero? (system* "gem" "build" (first-gemspec))))
 
 (define* (check #:key tests? test-target #:allow-other-keys)
   "Run the gem's test suite rake task TEST-TARGET.  Skip the tests if TESTS?
-- 
2.5.0

-- 
David Thompson
GPG Key: 0FF1D807

reply via email to

[Prev in Thread] Current Thread [Next in Thread]